.. _instrumentation_toplevel:

Alternate Class Instrumentation
================================

.. automodule:: sqlalchemy.ext.instrumentation

API Reference
-------------

.. autodata:: INSTRUMENTATION_MANAGER

.. autoclass:: sqlalchemy.orm.instrumentation.InstrumentationFactory

.. autoclass:: InstrumentationManager
    :members:
    :undoc-members:

.. autodata:: instrumentation_finders

.. autoclass:: ExtendedInstrumentationRegistry
    :members:



